/// Copyright Thomas Nagy 2007
/// License: QPL

#include "Szines.h"

/*!
 * @praise Vishnu
 */
szn::szn()
<%
	kidlgz=QString("Color");
	jlzpnt=QColor("#000000");
	kitzjl=QColor("#ffffff");
	irnyjl=QColor("#000000");
%>

